/*
 * [AlreadySent.java]
 *
 * Summary: Tracks whether an email has already been processed previously. Just in case ISP gives it to us twice.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2002-08-29
 */
package com.mindprod.bulk;

import java.io.Serializable;

/**
 * Tracks whether an email has already been processed previously. Just in case ISP gives it to us twice.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2002-08-29
 * @since 2002-08-29
 */
@SuppressWarnings( { "FieldCanBeLocal" } )
public final class AlreadySent implements Serializable
    {
    /**
     * to prevent spurious InvalidClassExceptions.
     */
    static final long serialVersionUID = 1L;

    /**
     * ID of email already sent.  These objects are in a keyed HashMap with id as key, so we don't really need the key
     * internally.
     */
    @SuppressWarnings( { "UnusedDeclaration" } )
    private final String id1;

    /**
     * timestamp of last time we processed and relayed this email. milliseconds since 1970-01-01
     */
    private final long whenSent;

    /**
     * Normal constructor
     *
     * @param id Id of email we are relaying.
     */
    public AlreadySent( String id )
        {
        this.id1 = id.trim().toLowerCase();
        this.whenSent = System.currentTimeMillis();
        }

    /**
     * Should this id be culled from the cache?
     *
     * @return true if yes
     */
    boolean shouldCull()
        {
        return whenSent + CustConfig.CULL_INTERVAL < System.currentTimeMillis();
        }
    }
